@@ -11,7 +11,7 @@ csvFile= csvRoot
 
 
 # 准备入模的数据，已经完成清洗
-makeModelDataFillnaFile = 'model_data_xgb_201912_lianjia_30'
+makeModelDataFillnaFile = 'model_data'
 ModelDataFillnaFile = 'only_model_data'
 
 
@@ -39,5 +39,5 @@ woe_file_output = False
 
 # id 和 y 的变量命名
 # col_head = ['cus_num', 'y']
-col_head = ['employee_no', 'bad']
+col_head = ['id', 'bad']
 
